<!--
 * @Author: Wenyu Ouyang
 * @Date: 2022-05-28 17:46:32
 * @LastEditTime: 2023-07-30 14:34:27
 * @LastEditors: Wenyu Ouyang
 * @Description: README for torchhydro
 * @FilePath: \torchhydro\README.md
 * Copyright (c) 2021-2022 Wenyu Ouyang. All rights reserved.
-->
# torchhydro


[![image](https://img.shields.io/pypi/v/torchhydro.svg)](https://pypi.python.org/pypi/torchhydro)
[![image](https://img.shields.io/conda/vn/conda-forge/torchhydro.svg)](https://anaconda.org/conda-forge/torchhydro)


**datasets, samplers, transforms, and pre-trained models for hydrology and water resources**


-   Free software: BSD license
-   Documentation: https://OuyangWenyu.github.io/torchhydro
    

## Features

-   TODO

## Credits

This package is inspired by [TorchGeo](https://torchgeo.readthedocs.io/en/stable/).

It was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
